# Welcome to securities_exchange


[![image](https://img.shields.io/pypi/v/securities_exchange.svg)](https://pypi.python.org/pypi/securities_exchange)


**A toy example of a Security Exchange in python**

-   Free software: MIT License

## Features

-   TODO
